<?php

namespace Litecms\Powerunit\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Powerunit\Models\PowerUnit;

class PowerUnitPolicy
{

    /**
     * Determine if the given user can view the power_unit.
     *
     * @param UserPolicy $user
     * @param PowerUnit $power_unit
     *
     * @return bool
     */
    public function view(UserPolicy $user, PowerUnit $power_unit)
    {
        if ($user->canDo('powerunit.power_unit.view') && $user->isAdmin()) {
            return true;
        }

        return $power_unit->user_id == user_id() && $power_unit->user_type == user_type();
    }

    /**
     * Determine if the given user can create a power_unit.
     *
     * @param UserPolicy $user
     * @param PowerUnit $power_unit
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('powerunit.power_unit.create');
    }

    /**
     * Determine if the given user can update the given power_unit.
     *
     * @param UserPolicy $user
     * @param PowerUnit $power_unit
     *
     * @return bool
     */
    public function update(UserPolicy $user, PowerUnit $power_unit)
    {
        if ($user->canDo('powerunit.power_unit.edit') && $user->isAdmin()) {
            return true;
        }

        return $power_unit->user_id == user_id() && $power_unit->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given power_unit.
     *
     * @param UserPolicy $user
     * @param PowerUnit $power_unit
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, PowerUnit $power_unit)
    {
        return $power_unit->user_id == user_id() && $power_unit->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given power_unit.
     *
     * @param UserPolicy $user
     * @param PowerUnit $power_unit
     *
     * @return bool
     */
    public function verify(UserPolicy $user, PowerUnit $power_unit)
    {
        if ($user->canDo('powerunit.power_unit.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given power_unit.
     *
     * @param UserPolicy $user
     * @param PowerUnit $power_unit
     *
     * @return bool
     */
    public function approve(UserPolicy $user, PowerUnit $power_unit)
    {
        if ($user->canDo('powerunit.power_unit.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
