<?php

namespace Litecms\Powerunit\Providers;

use Illuminate\Support\ServiceProvider;

class PowerunitServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'powerunit');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'powerunit');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerPowerunit();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerPowerunit()
    {
        $this->app->bind('powerunit', function($app) {
            return new Powerunit($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Powerunit', 'Lavalite\Powerunit\Facades\Powerunit');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litecms.powerunit', function ($app) {
            return $this->app->make('Litecms\Powerunit\Powerunit');
        });

                // Bind PowerUnit to repository
        $this->app->bind(
            'Litecms\Powerunit\Interfaces\PowerUnitRepositoryInterface',
            \Litecms\Powerunit\Repositories\Eloquent\PowerUnitRepository::class
        );

        $this->app->register(\Litecms\Powerunit\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Powerunit\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and powerunit's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/powerunit.php', 'powerunit'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakePowerunit::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.powerunit'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/powerunit.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/powerunit')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/powerunit')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
